# Copyright 2016 Red Hat, Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
from debtcollector import moves

from tempest.lib.services.volume.v3 import snapshot_manage_client


SnapshotManageClient = moves.moved_class(
    snapshot_manage_client.SnapshotManageClient, 'SnapshotManageClient',
    __name__, version="Rocky", removal_version='?')
